@@ -133,6 +133,7 @@
 #include "userport_synergy_joystick.h"
 #include "userport_wic64.h"
 #include "userport_woj_joystick.h"
+#include "userport_funmp3.h"
 #include "vice-event.h"
 #include "vicii.h"
 #include "vicii-mem.h"
@@ -196,7 +197,7 @@ static const trap_t scpu64_serial_traps[] = {
     { NULL, 0, 0, { 0, 0, 0 }, NULL, NULL, NULL }
 };
 
-static log_t scpu64_log = LOG_ERR;
+static log_t scpu64_log = LOG_DEFAULT;
 static machine_timing_t machine_timing;
 
 /* ------------------------------------------------------------------------ */
@@ -538,26 +539,15 @@ int machine_resources_init(void)
         init_resource_fail("userport devices");
         return -1;
     }
-    if (parallel_cable_cpu_resources_init() < 0) {
-        init_resource_fail("userport parallel drive cable");
-        return -1;
-    }
-    if (rsuser_resources_init() < 0) {
-        init_resource_fail("rsuser");
-        return -1;
-    }
     if (serial_resources_init() < 0) {
         init_resource_fail("serial");
         return -1;
     }
+    /* CAUTION: must come after userport and serial */
     if (printer_resources_init() < 0) {
         init_resource_fail("printer");
         return -1;
     }
-    if (printer_userport_resources_init() < 0) {
-        init_resource_fail("userport printer");
-        return -1;
-    }
     if (init_joyport_ports() < 0) {
         init_resource_fail("joyport ports");
         return -1;
@@ -625,88 +615,6 @@ int machine_resources_init(void)
         init_resource_fail("scpu64 glue");
         return -1;
     }
-    if (userport_joystick_cga_resources_init() < 0) {
-        init_resource_fail("userport cga joystick");
-        return -1;
-    }
-    if (userport_joystick_pet_resources_init() < 0) {
-        init_resource_fail("userport pet joystick");
-        return -1;
-    }
-    if (userport_joystick_hummer_resources_init() < 0) {
-        init_resource_fail("userport hummer joystick");
-        return -1;
-    }
-    if (userport_joystick_oem_resources_init() < 0) {
-        init_resource_fail("userport oem joystick");
-        return -1;
-    }
-    if (userport_joystick_hit_resources_init() < 0) {
-        init_resource_fail("userport hit joystick");
-        return -1;
-    }
-    if (userport_joystick_kingsoft_resources_init() < 0) {
-        init_resource_fail("userport kingsoft joystick");
-        return -1;
-    }
-    if (userport_joystick_starbyte_resources_init() < 0) {
-        init_resource_fail("userport starbyte joystick");
-        return -1;
-    }
-    if (userport_joystick_synergy_resources_init() < 0) {
-        init_resource_fail("userport synergy joystick");
-        return -1;
-    }
-    if (userport_joystick_woj_resources_init() < 0) {
-        init_resource_fail("userport woj joystick");
-        return -1;
-    }
-    if (userport_spt_joystick_resources_init() < 0) {
-        init_resource_fail("userport stupid pet tricks joystick");
-        return -1;
-    }
-    if (userport_dac_resources_init() < 0) {
-        init_resource_fail("userport dac");
-        return -1;
-    }
-    if (userport_digimax_resources_init() < 0) {
-        init_resource_fail("userport digimax");
-        return -1;
-    }
-    if (userport_rtc_58321a_resources_init() < 0) {
-        init_resource_fail("userport rtc (58321a)");
-        return -1;
-    }
-    if (userport_rtc_ds1307_resources_init() < 0) {
-        init_resource_fail("userport rtc (ds1307)");
-        return -1;
-    }
-    if (userport_4bit_sampler_resources_init() < 0) {
-        init_resource_fail("userport 4bit sampler");
-        return -1;
-    }
-    if (userport_8bss_resources_init() < 0) {
-        init_resource_fail("userport 8bit stereo sampler");
-        return -1;
-    }
-    if (userport_superpad64_resources_init() < 0) {
-        init_resource_fail("userport superpad64");
-        return -1;
-    }
-    if (userport_petscii_snespad_resources_init() < 0) {
-        init_resource_fail("userport petscii snes pad");
-        return -1;
-    }
-#ifdef HAVE_LIBCURL
-    if (userport_wic64_resources_init() < 0) {
-        init_resource_fail("userport wic64");
-        return -1;
-    }
-#endif
-    if (userport_io_sim_resources_init() < 0) {
-        init_resource_fail("userport I/O simulation");
-        return -1;
-    }
     if (cartio_resources_init() < 0) {
         init_resource_fail("cartio");
         return -1;
@@ -736,11 +644,7 @@ void machine_resources_shutdown(void)
     drive_resources_shutdown();
     cartridge_resources_shutdown();
     rombanks_resources_shutdown();
-    userport_rtc_58321a_resources_shutdown();
-    userport_rtc_ds1307_resources_shutdown();
-#ifdef HAVE_LIBCURL
-    userport_wic64_resources_shutdown();
-#endif
+    userport_resources_shutdown();
     cartio_shutdown();
     fsdevice_resources_shutdown();
     disk_image_resources_shutdown();
@@ -771,10 +675,6 @@ int machine_cmdline_options_init(void)
         init_cmdline_options_fail("rs232drv");
         return -1;
     }
-    if (rsuser_cmdline_options_init() < 0) {
-        init_cmdline_options_fail("rsuser");
-        return -1;
-    }
     if (serial_cmdline_options_init() < 0) {
         init_cmdline_options_fail("serial");
         return -1;
@@ -783,10 +683,6 @@ int machine_cmdline_options_init(void)
         init_cmdline_options_fail("printer");
         return -1;
     }
-    if (printer_userport_cmdline_options_init() < 0) {
-        init_cmdline_options_fail("userport printer");
-        return -1;
-    }
     if (joyport_cmdline_options_init() < 0) {
         init_cmdline_options_fail("joyport");
         return -1;
@@ -857,20 +753,6 @@ int machine_cmdline_options_init(void)
         init_cmdline_options_fail("scpu64 glue");
         return -1;
     }
-    if (userport_rtc_58321a_cmdline_options_init() < 0) {
-        init_cmdline_options_fail("userport rtc (58321a)");
-        return -1;
-    }
-    if (userport_rtc_ds1307_cmdline_options_init() < 0) {
-        init_cmdline_options_fail("userport rtc (ds1307)");
-        return -1;
-    }
-#ifdef HAVE_LIBCURL
-    if (userport_wic64_cmdline_options_init() < 0) {
-        init_cmdline_options_fail("userport wic64");
-        return -1;
-    }
-#endif
     if (cartio_cmdline_options_init() < 0) {
         init_cmdline_options_fail("cartio");
         return -1;
@@ -985,6 +867,9 @@ int machine_specific_init(void)
 
     /* Initialize userport based sound chips */
     userport_dac_sound_chip_init();
+#if defined(USE_MPG123) && defined (HAVE_GLOB_H)
+    userport_funmp3_sound_chip_init();
+#endif
 
     drive_sound_init();
     video_sound_init();
